[qet] [4506] Change the Z value of conducteur (11) to be upper than an element ( 10). |
[ Thread Index |
Date Index
| More lists.tuxfamily.org/qet Archives
]
Revision: 4506
Author: blacksun
Date: 2016-05-23 15:57:01 +0200 (Mon, 23 May 2016)
Log Message:
-----------
Change the Z value of conducteur (11) to be upper than an element (10).
Modified Paths:
--------------
trunk/sources/qetgraphicsitem/conductor.cpp
Modified: trunk/sources/qetgraphicsitem/conductor.cpp
===================================================================
--- trunk/sources/qetgraphicsitem/conductor.cpp 2016-05-23 10:34:09 UTC (rev 4505)
+++ trunk/sources/qetgraphicsitem/conductor.cpp 2016-05-23 13:57:01 UTC (rev 4506)
@@ -61,8 +61,8 @@
else if (p2->diagram())
properties_ = p2->diagram()->defaultConductorProperties;
- //set Zvalue at 9 to be upper than the DiagramImageItem and bottom of element(10)
- setZValue(9);
+ //set Zvalue at 11 to be upper than the DiagramImageItem and element
+ setZValue(11);
previous_z_value = zValue();
//Add this conductor to the list of conductor of each of the two terminal